!******************************************************************************!
!                                                                              !
!    class_vertices.f90                                                        !
!    is part of RECOLA2 (REcursive Computation of One Loop Amplitudes)2        !
!                                                                              !
!    Copyright (C) 2016-2018 Ansgar Denner, Jean-Nicolas Lang and              !
!                            Sandro Uccirati                                   !
!                                                                              !
!    RECOLA2 is licenced under the GNU GPL version 3,                          !
!    see COPYING for details.                                                  !
!                                                                              !
!******************************************************************************!
!                                                           .---.              !
!                                                          /  .  \             !
!                                                         |\_/|   |            !
!                                                         |   |  /|            !
!          .----------------------------------------------------' |            !
!         /  .-.   class_vertices.f90                             |            !
!        |  /   \  This code was generated with REPT1L.           |            !
!        | |\_.  | Change this file and you get what you deserve. |            !
!        |\|  | /| Author: J.N. Lang                              |            !
!        | `---' | UFO date: 07/2017                              |            !
!        |       | UFO version: 1.0                               |            !
!        |       | Generation date: 2018-11-28 18:50             /             !
!        |       |----------------------------------------------'              !
!        \       |                                                             !
!         \     /                                                              !
!          `---'                                                               !
!******************************************************************************!
module class_vertices
  use fill_couplings
  use class_particles
  use class_ctparameters
  use fill_ctparameters, only: init_CTparameters_mdl
  use particle_keys, only: createParticleConfig
  use dictionary, only: dict,dict_get_value,dict_init
  use constants_mdl, only: Nc
  implicit none
  save

  interface get_vertex_mdl
    module procedure get_vertex3_mdl, get_vertex4_mdl, get_vertexN_mdl
  end interface

  type Branch
    integer :: lorentz_id
    integer :: perm
    integer, allocatable :: couplings(:)
    integer, dimension(n_orders) :: coupling_order
    integer :: color_id
    integer :: colorfac_id
    ! Propagator extension (only supported for massive vectors)
    ! 0: Usual propagator
    ! 1: Rxi-propagator part with pole @ M_V^2
    ! 2: Rxi-propagator part with pole @ \xi*M_V^2
    integer :: pext
  end type

  type Vertex
    type(Branch), allocatable :: branch(:)
    type(Branch), allocatable :: branchCT(:)
    type(Branch), allocatable :: branchR2(:)
  end type

  logical :: vertices_init = .false.
  logical :: vertices_filled = .false.
    interface createCurrent
      module procedure createCurrent2, createCurrent3, createCurrent4,         &
      createCurrent5, createCurrent6, createCurrent7, createCurrent8
    end interface 
  integer, parameter :: n_vertices = 1248
  type(Vertex) :: vertices(0:n_vertices-1)

  ! Defines the maximum allowed number of legs participating at a vertex
  integer, parameter :: max_leg_multiplicity = 4

  integer, parameter :: FFaS0 = 1
  integer, parameter :: FFaS1 = 2
  integer, parameter :: FFaS2 = 3
  integer, parameter :: VFaF0 = 4
  integer, parameter :: VFaF1 = 5
  integer, parameter :: SVVS0 = 6
  integer, parameter :: VVVV0 = 7
  integer, parameter :: UUaS0 = 8
  integer, parameter :: UUaV0 = 9
  integer, parameter :: SUUa0 = 10
  integer, parameter :: VVSS0 = 11
  integer, parameter :: UaSU0 = 12
  integer, parameter :: FFaV0 = 13
  integer, parameter :: FFaV1 = 14
  integer, parameter :: VVV0 = 15
  integer, parameter :: FSFa0 = 16
  integer, parameter :: FSFa1 = 17
  integer, parameter :: FSFa2 = 18
  integer, parameter :: VVS0 = 19
  integer, parameter :: FaVF0 = 20
  integer, parameter :: FaVF1 = 21
  integer, parameter :: UaVU0 = 22
  integer, parameter :: FaF0 = 23
  integer, parameter :: FaF1 = 24
  integer, parameter :: FaF2 = 25
  integer, parameter :: VSVS0 = 26
  integer, parameter :: FVFa0 = 27
  integer, parameter :: FVFa1 = 28
  integer, parameter :: VUaU0 = 29
  integer, parameter :: USUa0 = 30
  integer, parameter :: VV0 = 31
  integer, parameter :: VV1 = 32
  integer, parameter :: VV2 = 33
  integer, parameter :: VV3 = 34
  integer, parameter :: SVSV0 = 35
  integer, parameter :: FaFS0 = 36
  integer, parameter :: FaFS1 = 37
  integer, parameter :: FaFS2 = 38
  integer, parameter :: FaFV0 = 39
  integer, parameter :: FaFV1 = 40
  integer, parameter :: SSSS0 = 41
  integer, parameter :: VS0 = 42
  integer, parameter :: SFFa0 = 43
  integer, parameter :: SFFa1 = 44
  integer, parameter :: SFFa2 = 45
  integer, parameter :: VUUa0 = 46
  integer, parameter :: SFaF0 = 47
  integer, parameter :: SFaF1 = 48
  integer, parameter :: SFaF2 = 49
  integer, parameter :: SVV0 = 50
  integer, parameter :: FaSF0 = 51
  integer, parameter :: FaSF1 = 52
  integer, parameter :: FaSF2 = 53
  integer, parameter :: SVS0 = 54
  integer, parameter :: FFa0 = 55
  integer, parameter :: FFa1 = 56
  integer, parameter :: FFa2 = 57
  integer, parameter :: VSS0 = 58
  integer, parameter :: VSV0 = 59
  integer, parameter :: SS0 = 60
  integer, parameter :: SS1 = 61
  integer, parameter :: SS2 = 62
  integer, parameter :: SSVV0 = 63
  integer, parameter :: SSV0 = 64
  integer, parameter :: SV0 = 65
  integer, parameter :: SSS0 = 66
  integer, parameter :: UVUa0 = 67
  integer, parameter :: VSSV0 = 68
  integer, parameter :: UaUS0 = 69
  integer, parameter :: VFFa0 = 70
  integer, parameter :: VFFa1 = 71
  integer, parameter :: SUaU0 = 72
  integer, parameter :: UaUV0 = 73
  complex(dp), parameter :: c1 = cmplx(1d0, 0d0, kind=dp)
  character(len=20), parameter :: c1f = "1"
  complex(dp), parameter :: c2 = cmplx(sq2/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c2f = "sq2/2"
  complex(dp), parameter :: c3 = cmplx(-sq2/(2d0*Nc), 0d0, kind=dp)
  character(len=20), parameter :: c3f = "-sq2/(2*Nc)"
  complex(dp), parameter :: c4 = cmplx(0d0, sq2/2d0, kind=dp)
  character(len=20), parameter :: c4f = "i_*sq2/2"
  complex(dp), parameter :: c5 = cmplx(0d0, -sq2/2d0, kind=dp)
  character(len=20), parameter :: c5f = "-i_*sq2/2"
  complex(dp), parameter :: c6 = cmplx(-1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c6f = "-1/2"
  complex(dp), parameter :: c7 = cmplx(1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c7f = "1/2"
  complex(dp), parameter :: c8 = cmplx(-1d0/Nc, 0d0, kind=dp)
  character(len=20), parameter :: c8f = "-1/Nc"
  complex(dp), dimension(1:8) :: colorcoeffs = (/c1, c2, c3, c4, c5, c6, c7, c8&
                                               /)
  character(len=20), dimension(1:8) :: colorcoeffs_form = (/c1f, c2f, c3f, c4f &
                 , c5f, c6f, c7f, c8f/)
  integer, dimension(1:73) :: lorentz_rank = (/0, 0, 0, 1, 1, 0, 0, 0, 1, 0, 0 &
                                             , 0, 0, 0, 1, 1, 1, 1, 0, 1, 1, 1 &
                                             , -1, -1, -1, 0, 1, 1, 1, 0, -1, -&
                                             1, -1, -1, 0, 0, 0, 0, 0, 0, 0, -1&
                                             , 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1 &
                                             , 1, -1, -1, -1, 1, 0, -1, -1, -1 &
                                             , 0, 1, -1, 0, 1, 0, 0, 1, 1, 0, 1&
                                             /)
  integer, dimension(1:73) :: recola_base = (/5, 9, 7, 53, 58, -2, -11, 1, 161 &
                                            , 1, -4, 1, 17, 15, 12, 27, 21, 25 &
                                            , 2, 51, 57, 166, 0, 0, 0, -3, 35, &
                                            31, 162, 1, 0, 0, 0, 0, -14, 6, 10 &
                                            , 8, 16, 18, -1, 0, 23, 28, 26, 163&
                                            , 43, 48, 46, 13, 41, 47, 45, 3, 0 &
                                            , 0, 0, 4, 14, 0, 0, 0, -12, 11, 0 &
                                            , 1, 165, -13, 1, 33, 36, 1, 164/)
  integer, dimension(1:73) :: propagator_extension = (/0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0/)
  character(len=*), parameter :: model_timestamp = "Wed Nov 28 18:37:27 2018"

  contains
    function get_timestamp_mdl() result(ret_timestamp)
      character(len=len(model_timestamp)) :: ret_timestamp
      ret_timestamp = model_timestamp
    end function get_timestamp_mdl

    function get_lorentz_rank_mdl(l_id) result(ret_lorentz_rank)
      integer, intent(in) :: l_id
      integer :: ret_lorentz_rank
      ret_lorentz_rank = lorentz_rank(l_id)
    end function get_lorentz_rank_mdl

    function get_propagator_extension_mdl(l_id) result(ret_pext)
      integer, intent(in) :: l_id
      integer :: ret_pext
      ret_pext = propagator_extension(l_id)
    end function get_propagator_extension_mdl

    function get_max_leg_multiplicity_mdl() result(ret_max_leg_multiplicity)
      integer :: ret_max_leg_multiplicity
      ret_max_leg_multiplicity = max_leg_multiplicity
    end function get_max_leg_multiplicity_mdl

    function is_model_init_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_init
    end function is_model_init_mdl

    function is_model_filled_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_filled
    end function is_model_filled_mdl

    subroutine get_vertex3_mdl(p1, p2, p3, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertex3_mdl

    subroutine get_vertex4_mdl(p1, p2, p3, p4, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3, p4
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, p4, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if
    end subroutine get_vertex4_mdl

    subroutine get_vertexN_mdl(particles, particleOut, vertex_ret)
      integer, intent(out)              :: vertex_ret
      integer, dimension(:), intent(in) :: particles
      integer, intent(in)               :: particleOut
      integer(kind=8)                   :: config
      integer                           :: address
      logical                           :: found_vertex

      call createParticleConfig(particles, particleOut, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertexN_mdl

    subroutine av(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branch(bid)%color_id = cid
      vertices(vid)%branch(bid)%colorfac_id = cfid
      vertices(vid)%branch(bid)%pext = pext
      vertices(vid)%branch(bid)%lorentz_id = lid
      vertices(vid)%branch(bid)%perm = perm
      vertices(vid)%branch(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branch(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branch(bid)%couplings(i) = cop(i)
      end do
    end subroutine av

    subroutine avCT(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchCT(bid)%color_id = cid
      vertices(vid)%branchCT(bid)%colorfac_id = cfid
      vertices(vid)%branchCT(bid)%pext = pext
      vertices(vid)%branchCT(bid)%lorentz_id = lid
      vertices(vid)%branchCT(bid)%perm = perm
      vertices(vid)%branchCT(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchCT(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchCT(bid)%couplings(i) = cop(i)
      end do
    end subroutine avCT

    subroutine avR2(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchR2(bid)%color_id = cid
      vertices(vid)%branchR2(bid)%colorfac_id = cfid
      vertices(vid)%branchR2(bid)%pext = pext
      vertices(vid)%branchR2(bid)%lorentz_id = lid
      vertices(vid)%branchR2(bid)%perm = perm
      vertices(vid)%branchR2(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchR2(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchR2(bid)%couplings(i) = cop(i)
      end do
    end subroutine avR2

    function get_colourfac_mdl(cfid)
      integer, intent(in) :: cfid
      complex(dp) :: get_colourfac_mdl
      get_colourfac_mdl = colorcoeffs(cfid)
    end function get_colourfac_mdl

    function get_colourfac_form_mdl(cfid)
      integer, intent(in) :: cfid
      character(len=20) :: get_colourfac_form_mdl
      get_colourfac_form_mdl = colorcoeffs_form(cfid)
    end function get_colourfac_form_mdl

  function get_recola_base_mdl(l_id) result(ret_rb)
      integer, intent(in) :: l_id
      integer :: ret_rb
      ret_rb = recola_base(l_id)
    end function get_recola_base_mdl

  subroutine get_vertex_branch_status_mdl(vx,xlp,branch_exists)
    integer, intent(in)  :: vx,xlp
    logical, intent(out) ::branch_exists
    select case (xlp)
    case(TreeBranch:LoopBranch)
      branch_exists = allocated(vertices(vx)%branch)
    case(CTBranch)
      branch_exists = allocated(vertices(vx)%branchCT)
    case(R2Branch)
      branch_exists = allocated(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_branch_status_mdl

  subroutine get_vertex_colour_branches_mdl(vx,xlp,cfids,nbranches)
    integer, allocatable, intent(out) :: cfids(:)
    integer, intent(out) :: nbranches
    integer, intent(in)  :: vx,xlp
    select case (xlp)
    case (TreeBranch:LoopBranch)
      allocate(cfids(size(vertices(vx)%branch)))
      cfids(:) = vertices(vx)%branch(0:)%color_id
      nbranches = size(vertices(vx)%branch)
    case(CTBranch)
      allocate(cfids(size(vertices(vx)%branchCT)))
      cfids(:) = vertices(vx)%branchCT(0:)%color_id
      nbranches = size(vertices(vx)%branchCT)
    case(R2Branch)
      allocate(cfids(size(vertices(vx)%branchR2)))
      cfids(:) = vertices(vx)%branchR2(0:)%color_id
      nbranches = size(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_colour_branches_mdl

  subroutine get_vertex_pext_mdl(vx,xlp,br,pext)
    integer, intent(in) :: vx,xlp,br
    integer, intent(out) :: pext
    select case (xlp)
    case (TreeBranch:LoopBranch)
      pext = vertices(vx)%branch(br)%pext
    case(CTBranch)
      pext = vertices(vx)%branchCT(br)%pext
    case(R2Branch)
      pext = vertices(vx)%branchR2(br)%pext
    end select
  end subroutine get_vertex_pext_mdl

  subroutine get_vertex_order_increase_mdl(vx,xlp,br,orderInc)
    integer, intent(in) :: vx,xlp,br
    integer, dimension(:), intent(out) :: orderInc
    select case (xlp)
    case (TreeBranch:LoopBranch)
      orderInc = vertices(vx)%branch(br)%coupling_order
    case(CTBranch)
      orderInc = vertices(vx)%branchCT(br)%coupling_order
    case(R2Branch)
      orderInc = vertices(vx)%branchR2(br)%coupling_order
    end select
  end subroutine get_vertex_order_increase_mdl

  subroutine get_vertex_lorentz_type_mdl(vx,xlp,br,lid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: lid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      lid = vertices(vx)%branch(br)%lorentz_id
    case(CTBranch)
      lid = vertices(vx)%branchCT(br)%lorentz_id
    case(R2Branch)
      lid = vertices(vx)%branchR2(br)%lorentz_id
    end select
  end subroutine get_vertex_lorentz_type_mdl

  subroutine get_vertex_perm_mdl(vx,xlp,br,perm)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: perm
    select case (xlp)
    case (TreeBranch:LoopBranch)
      perm = vertices(vx)%branch(br)%perm
    case(CTBranch)
      perm = vertices(vx)%branchCT(br)%perm
    case(R2Branch)
      perm = vertices(vx)%branchR2(br)%perm
    end select
  end subroutine get_vertex_perm_mdl

  subroutine get_vertex_colour_id_mdl(vx,xlp,br,cid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      cid = vertices(vx)%branch(br)%colorfac_id
    case(CTBranch)
      cid = vertices(vx)%branchCT(br)%colorfac_id
    case(R2Branch)
      cid = vertices(vx)%branchR2(br)%colorfac_id
    end select
  end subroutine get_vertex_colour_id_mdl

  function is_zero_coupling_vertex_mdl(vx,xlp,br) result(zero)
    use class_couplings, only: get_coupling_value_mdl
    use input_mdl, only: zerocut
    integer, intent(in)  :: vx,xlp,br
    logical              :: zero
    real(dp)             :: maxvalue
    integer              :: i

    zero = .false.
    select case (xlp)
    case (TreeBranch:LoopBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branch(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branch(br)%couplings(i-&
                1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(CTBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchCT(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchCT(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(R2Branch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchR2(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchR2(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    end select
  end function is_zero_coupling_vertex_mdl

  subroutine get_vertex_ncouplings_mdl(vx,xlp,br,ncouplings)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: ncouplings
    select case(xlp)
    case(TreeBranch, LoopBranch)
      ncouplings = size(vertices(vx)%branch(br)%couplings)
    case (CTBranch)
      ncouplings = size(vertices(vx)%branchCT(br)%couplings)
    case (R2Branch)
      ncouplings = size(vertices(vx)%branchR2(br)%couplings)
    end select
  end subroutine get_vertex_ncouplings_mdl

  subroutine get_vertex_coupling_ids_mdl(vx,xlp,br,cids)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cids(:)
    select case(xlp)
    case(TreeBranch, LoopBranch)
      cids(:) = vertices(vx)%branch(br)%couplings(:)
    case (CTBranch)
      cids(:) = vertices(vx)%branchCT(br)%couplings(:)
    case (R2Branch)
      cids(:) = vertices(vx)%branchR2(br)%couplings(:)
    end select
  end subroutine get_vertex_coupling_ids_mdl

    subroutine createCurrent2(P1, P2, id, check)
      integer, intent(in) :: P1, P2, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent2

    subroutine createCurrent3(P1, P2, P3, id, check)
      integer, intent(in) :: P1, P2, P3, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent3

    subroutine createCurrent4(P1, P2, P3, P4, id, check)
      integer, intent(in) :: P1, P2, P3, P4, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent4

    subroutine createCurrent5(P1, P2, P3, P4, P5, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent5

    subroutine createCurrent6(P1, P2, P3, P4, P5, P6, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent6

    subroutine createCurrent7(P1, P2, P3, P4, P5, P6, P7, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent7

    subroutine createCurrent8(P1, P2, P3, P4, P5, P6, P7, P8, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, P8, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, P8, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent8

    subroutine init_vertices_mdl()
      use constants_mdl
      use input_mdl, only: nx, error_mdl

      ! check if modelfile is compatible to drivers
      if (model_timestamp .ne. driver_timestamp) then
        call error_mdl("Model corrupted. Driver timestamp mismatch.", &
                      where='init_vertices')
      end if

      vertices_init = .true.
      call fill_couplings_mdl
      call init_CTparameters_mdl(.true.)
      call fill_CTcouplings_mdl
      call dict_init(2477)
      call createCurrents(.false.)

    end subroutine init_vertices_mdl

    subroutine createCurrents(check)
      logical, intent(in) :: check
      call createCurrent(P_WMinus, P_H, P_Z, P_GPlus, 1025, check)
      call createCurrent(P_A, P_GPlus, P_H, P_WMinus, 707, check)
      call createCurrent(P_t, P_tAnti, P_g, 89, check)
      call createCurrent(P_WPlus, P_GPlus, P_GMinus, P_WMinus, 81, check)
      call createCurrent(P_GPlus, P_b, P_tAnti, 306, check)
      call createCurrent(P_WPlus, P_H, P_H, P_WMinus, 232, check)
      call createCurrent(P_G0, P_H, P_A, 1134, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, 856, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_G0, 483, check)
      call createCurrent(P_t, P_tAnti, P_A, 377, check)
      call createCurrent(P_c, P_G0, P_cAnti, 269, check)
      call createCurrent(P_GPlus, P_A, P_Z, P_GMinus, 792, check)
      call createCurrent(P_H, P_GMinus, P_GPlus, P_H, 83, check)
      call createCurrent(P_nu_mu, P_muPlus, P_GMinus, 187, check)
      call createCurrent(P_H, P_A, P_GMinus, P_WPlus, 918, check)
      call createCurrent(P_H, P_ghWpAnti, P_ghWp, 586, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_H, 364, check)
      call createCurrent(P_tAnti, P_t, P_Z, 134, check)
      call createCurrent(P_H, P_tauPlus, P_tauMinus, 937, check)
      call createCurrent(P_G0, P_cAnti, P_c, 258, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_G0, 336, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_GPlus, 876, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_A, 469, check)
      call createCurrent(P_Z, P_H, P_WPlus, P_GMinus, 9, check)
      call createCurrent(P_H, P_H, P_A, P_Z, 1066, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, P_A, 541, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_A, 620, check)
      call createCurrent(P_H, P_WMinus, P_WPlus, 734, check)
      call createCurrent(P_Z, P_G0, P_GMinus, P_WPlus, 317, check)
      call createCurrent(P_A, P_WMinus, P_A, P_WPlus, 569, check)
      call createCurrent(P_muPlus, P_muMinus, 1111, check)
      call createCurrent(P_muMinus, P_muPlus, P_G0, 823, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, 761, check)
      call createCurrent(P_H, P_A, P_WMinus, P_GPlus, 544, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, 934, check)
      call createCurrent(P_G0, P_uAnti, P_u, 210, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, P_A, 407, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_GPlus, 182, check)
      call createCurrent(P_GPlus, P_Z, P_Z, P_GMinus, 194, check)
      call createCurrent(P_A, P_c, P_cAnti, 1008, check)
      call createCurrent(P_s, P_sAnti, P_H, 821, check)
      call createCurrent(P_t, P_tAnti, P_G0, 936, check)
      call createCurrent(P_g, P_WPlus, P_WMinus, P_g, 1167, check)
      call createCurrent(P_GPlus, P_GMinus, P_g, P_g, 1180, check)
      call createCurrent(P_H, P_G0, P_G0, 680, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, P_Z, 370, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, 644, check)
      call createCurrent(P_d, P_WPlus, P_uAnti, 836, check)
      call createCurrent(P_G0, P_WPlus, P_Z, P_GMinus, 896, check)
      call createCurrent(P_A, P_uAnti, P_u, 535, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_A, 22, check)
      call createCurrent(P_g, P_cAnti, P_c, 246, check)
      call createCurrent(P_H, P_H, P_A, P_A, 1209, check)
      call createCurrent(P_WMinus, P_G0, P_G0, P_WPlus, 354, check)
      call createCurrent(P_uAnti, P_d, P_WPlus, 921, check)
      call createCurrent(P_A, P_Z, P_g, P_g, 1236, check)
      call createCurrent(P_GMinus, P_t, P_bAnti, 439, check)
      call createCurrent(P_GMinus, P_WPlus, P_WMinus, P_GPlus, 564, check)
      call createCurrent(P_WPlus, P_WMinus, P_GMinus, P_GPlus, 710, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, 673, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_Z, 788, check)
      call createCurrent(P_H, P_H, 1100, check)
      call createCurrent(P_Z, P_g, P_Z, P_g, 1198, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, 939, check)
      call createCurrent(P_uAnti, P_u, 1064, check)
      call createCurrent(P_nu_e, P_ePlus, P_WMinus, 574, check)
      call createCurrent(P_sAnti, P_g, P_s, 320, check)
      call createCurrent(P_Z, P_A, P_GPlus, P_GMinus, 549, check)
      call createCurrent(P_H, P_ghWmAnti, P_ghWm, 904, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WPlus, 412, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_Z, 473, check)
      call createCurrent(P_H, P_uAnti, P_u, 900, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_H, 516, check)
      call createCurrent(P_d, P_Z, P_dAnti, 698, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, 366, check)
      call createCurrent(P_GPlus, P_G0, P_A, P_WMinus, 773, check)
      call createCurrent(P_G0, P_WMinus, P_G0, P_WPlus, 332, check)
      call createCurrent(P_s, P_g, P_sAnti, 222, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_H, 348, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_Z, 659, check)
      call createCurrent(P_G0, P_G0, P_Z, P_Z, 292, check)
      call createCurrent(P_Z, P_u, P_uAnti, 456, check)
      call createCurrent(P_sAnti, P_s, 1133, check)
      call createCurrent(P_WMinus, P_nu_mu, P_muPlus, 778, check)
      call createCurrent(P_GMinus, P_GPlus, P_H, P_H, 1001, check)
      call createCurrent(P_WPlus, P_Z, P_G0, P_GMinus, 260, check)
      call createCurrent(P_c, P_sAnti, P_GMinus, 545, check)
      call createCurrent(P_H, P_WMinus, P_WPlus, P_H, 753, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, 1026, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, 158, check)
      call createCurrent(P_H, P_ghZAnti, P_ghZ, 913, check)
      call createCurrent(P_G0, P_eMinus, P_ePlus, 343, check)
      call createCurrent(P_bAnti, P_GMinus, P_t, 819, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, 699, check)
      call createCurrent(P_ghWmAnti, P_H, P_ghWm, 68, check)
      call createCurrent(P_muMinus, P_WPlus, P_nu_muAnti, 744, check)
      call createCurrent(P_g, P_c, P_cAnti, 402, check)
      call createCurrent(P_nu_e, P_GMinus, P_ePlus, 156, check)
      call createCurrent(P_GPlus, P_GPlus, P_GMinus, P_GMinus, 149, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_A, 554, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, 339, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_H, 894, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, 1142, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_GPlus, 658, check)
      call createCurrent(P_Z, P_H, P_A, P_H, 1122, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, 841, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_G0, 989, check)
      call createCurrent(P_muMinus, P_muPlus, P_H, 8, check)
      call createCurrent(P_g, P_GMinus, P_GPlus, P_g, 1212, check)
      call createCurrent(P_u, P_dAnti, P_WMinus, 633, check)
      call createCurrent(P_Z, P_tauPlus, P_tauMinus, 643, check)
      call createCurrent(P_WMinus, P_dAnti, P_u, 424, check)
      call createCurrent(P_H, P_WPlus, P_A, P_GMinus, 614, check)
      call createCurrent(P_WPlus, P_WMinus, P_H, P_H, 837, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, 910, check)
      call createCurrent(P_WPlus, P_GMinus, P_GPlus, P_WMinus, 478, check)
      call createCurrent(P_dAnti, P_d, 1125, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, 178, check)
      call createCurrent(P_cAnti, P_G0, P_c, 371, check)
      call createCurrent(P_Z, P_WPlus, P_A, P_WMinus, 383, check)
      call createCurrent(P_s, P_sAnti, P_Z, 498, check)
      call createCurrent(P_s, P_A, P_sAnti, 491, check)
      call createCurrent(P_g, P_H, P_g, 1176, check)
      call createCurrent(P_GMinus, P_GPlus, 1128, check)
      call createCurrent(P_WPlus, P_Z, P_A, P_WMinus, 249, check)
      call createCurrent(P_H, P_GPlus, P_GMinus, P_H, 571, check)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, 851, check)
      call createCurrent(P_GMinus, P_g, P_GPlus, P_g, 1146, check)
      call createCurrent(P_Z, P_Z, P_g, P_g, 1151, check)
      call createCurrent(P_G0, P_WMinus, P_Z, P_GPlus, 712, check)
      call createCurrent(P_Z, P_Z, P_A, P_A, 1224, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_A, 1061, check)
      call createCurrent(P_Z, P_GPlus, P_H, P_WMinus, 814, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, P_A, 973, check)
      call createCurrent(P_Z, P_H, P_A, 1073, check)
      call createCurrent(P_g, P_d, P_dAnti, 37, check)
      call createCurrent(P_H, P_H, P_Z, P_Z, 115, check)
      call createCurrent(P_H, P_G0, P_A, 1053, check)
      call createCurrent(P_WPlus, P_A, P_H, P_GMinus, 41, check)
      call createCurrent(P_H, P_Z, P_Z, P_H, 432, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, 87, check)
      call createCurrent(P_A, P_nu_tau, P_nu_tauAnti, 1136, check)
      call createCurrent(P_Z, P_WPlus, P_Z, P_WMinus, 277, check)
      call createCurrent(P_cAnti, P_g, P_c, 917, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_Z, 241, check)
      call createCurrent(P_A, P_cAnti, P_c, 112, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, 722, check)
      call createCurrent(P_G0, P_H, P_Z, 405, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_A, 600, check)
      call createCurrent(P_GMinus, P_Z, P_A, P_GPlus, 247, check)
      call createCurrent(P_WPlus, P_tauMinus, P_nu_tauAnti, 155, check)
      call createCurrent(P_Z, P_A, P_G0, P_G0, 1059, check)
      call createCurrent(P_Z, P_c, P_cAnti, 899, check)
      call createCurrent(P_GMinus, P_bAnti, P_t, 143, check)
      call createCurrent(P_G0, P_Z, P_G0, P_A, 1129, check)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, 909, check)
      call createCurrent(P_WPlus, P_H, P_A, P_GMinus, 128, check)
      call createCurrent(P_ePlus, P_Z, P_eMinus, 995, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, 631, check)
      call createCurrent(P_bAnti, P_b, P_g, 305, check)
      call createCurrent(P_cAnti, P_Z, P_c, 504, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, P_Z, 828, check)
      call createCurrent(P_Z, P_G0, P_G0, P_A, 1052, check)
      call createCurrent(P_g, P_tAnti, P_t, 719, check)
      call createCurrent(P_GPlus, P_GMinus, 1120, check)
      call createCurrent(P_G0, P_g, P_g, P_G0, 1217, check)
      call createCurrent(P_eMinus, P_WPlus, P_nu_eAnti, 505, check)
      call createCurrent(P_t, P_H, P_tAnti, 189, check)
      call createCurrent(P_cAnti, P_A, P_c, 329, check)
      call createCurrent(P_g, P_g, P_H, 1215, check)
      call createCurrent(P_GPlus, P_GMinus, P_H, P_H, 303, check)
      call createCurrent(P_muPlus, P_muMinus, P_H, 745, check)
      call createCurrent(P_GPlus, P_GMinus, P_WPlus, P_WMinus, 228, check)
      call createCurrent(P_Z, P_ePlus, P_eMinus, 1046, check)
      call createCurrent(P_H, P_GMinus, P_Z, P_WPlus, 243, check)
      call createCurrent(P_tauPlus, P_G0, P_tauMinus, 381, check)
      call createCurrent(P_tauMinus, P_WPlus, P_nu_tauAnti, 751, check)
      call createCurrent(P_A, P_H, P_H, P_A, 1204, check)
      call createCurrent(P_d, P_uAnti, P_GPlus, 647, check)
      call createCurrent(P_Z, P_Z, P_Z, P_Z, 1197, check)
      call createCurrent(P_u, P_GMinus, P_dAnti, 955, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_G0, 437, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_Z, 849, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, 215, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_Z, 1039, check)
      call createCurrent(P_H, P_H, P_Z, P_A, 1074, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_H, 415, check)
      call createCurrent(P_Z, P_Z, P_GPlus, P_GMinus, 929, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, 477, check)
      call createCurrent(P_t, P_Z, P_tAnti, 717, check)
      call createCurrent(P_H, P_tauMinus, P_tauPlus, 213, check)
      call createCurrent(P_G0, P_dAnti, P_d, 639, check)
      call createCurrent(P_t, P_g, P_tAnti, 809, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, 986, check)
      call createCurrent(P_H, P_g, P_H, P_g, 1182, check)
      call createCurrent(P_A, P_A, P_G0, P_G0, 1192, check)
      call createCurrent(P_s, P_Z, P_sAnti, 1019, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_Z, 123, check)
      call createCurrent(P_t, P_GMinus, P_bAnti, 757, check)
      call createCurrent(P_H, P_sAnti, P_s, 440, check)
      call createCurrent(P_Z, P_nu_muAnti, P_nu_mu, 351, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, 542, check)
      call createCurrent(P_nu_e, P_WMinus, P_ePlus, 19, check)
      call createCurrent(P_H, P_cAnti, P_c, 1012, check)
      call createCurrent(P_ghG, P_ghGAnti, P_g, 489, check)
      call createCurrent(P_bAnti, P_b, P_G0, 503, check)
      call createCurrent(P_GMinus, P_A, P_H, P_WPlus, 290, check)
      call createCurrent(P_H, P_G0, P_H, P_G0, 726, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, 926, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, P_Z, 978, check)
      call createCurrent(P_Z, P_nu_tau, P_nu_tauAnti, 281, check)
      call createCurrent(P_WPlus, P_A, P_A, P_WMinus, 772, check)
      call createCurrent(P_nu_tau, P_A, P_nu_tauAnti, 1131, check)
      call createCurrent(P_H, P_H, P_GPlus, P_GMinus, 308, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, 825, check)
      call createCurrent(P_GMinus, P_dAnti, P_u, 62, check)
      call createCurrent(P_WPlus, P_nu_muAnti, P_muMinus, 623, check)
      call createCurrent(P_G0, P_WPlus, P_A, P_GMinus, 543, check)
      call createCurrent(P_muMinus, P_muPlus, P_A, 50, check)
      call createCurrent(P_G0, P_u, P_uAnti, 582, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, 789, check)
      call createCurrent(P_A, P_Z, P_Z, P_A, 1216, check)
      call createCurrent(P_GMinus, P_u, P_dAnti, 969, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, 30, check)
      call createCurrent(P_WMinus, P_c, P_sAnti, 369, check)
      call createCurrent(P_A, P_muPlus, P_muMinus, 61, check)
      call createCurrent(P_H, P_A, P_A, P_H, 1189, check)
      call createCurrent(P_WMinus, P_GMinus, P_GPlus, P_WPlus, 196, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, 229, check)
      call createCurrent(P_u, P_A, P_uAnti, 113, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, 706, check)
      call createCurrent(P_H, P_Z, P_GMinus, P_WPlus, 500, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, 661, check)
      call createCurrent(P_H, P_g, P_g, 1173, check)
      call createCurrent(P_uAnti, P_G0, P_u, 619, check)
      call createCurrent(P_A, P_u, P_uAnti, 762, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, P_A, 160, check)
      call createCurrent(P_A, P_A, P_GPlus, P_GMinus, 119, check)
      call createCurrent(P_G0, P_c, P_cAnti, 414, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, 1011, check)
      call createCurrent(P_WMinus, P_WPlus, P_g, P_g, 1170, check)
      call createCurrent(P_dAnti, P_d, P_Z, 138, check)
      call createCurrent(P_ePlus, P_GMinus, P_nu_e, 691, check)
      call createCurrent(P_Z, P_G0, P_GPlus, P_WMinus, 768, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_G0, 372, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, 565, check)
      call createCurrent(P_G0, P_A, P_WMinus, P_GPlus, 613, check)
      call createCurrent(P_b, P_bAnti, P_G0, 508, check)
      call createCurrent(P_GPlus, P_A, P_G0, P_WMinus, 77, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, 195, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, 152, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, 237, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_Z, 713, check)
      call createCurrent(P_dAnti, P_d, P_G0, 804, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, 1005, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_G0, 976, check)
      call createCurrent(P_G0, P_ghWm, P_ghWmAnti, 653, check)
      call createCurrent(P_G0, P_A, P_WPlus, P_GMinus, 219, check)
      call createCurrent(P_tauPlus, P_A, P_tauMinus, 166, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_A, 263, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_A, 1088, check)
      call createCurrent(P_WMinus, P_g, P_WPlus, P_g, 1190, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, P_Z, 293, check)
      call createCurrent(P_dAnti, P_GMinus, P_u, 29, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_A, 47, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, 974, check)
      call createCurrent(P_cAnti, P_c, P_g, 1018, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, 599, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_G0, 636, check)
      call createCurrent(P_g, P_G0, P_g, P_G0, 1185, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, 59, check)
      call createCurrent(P_ePlus, P_eMinus, P_A, 1015, check)
      call createCurrent(P_A, P_A, P_H, 1196, check)
      call createCurrent(P_Z, P_tauMinus, P_tauPlus, 391, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_Z, 1029, check)
      call createCurrent(P_Z, P_b, P_bAnti, 251, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_Z, 794, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WPlus, 24, check)
      call createCurrent(P_g, P_A, P_g, P_Z, 1208, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_A, 462, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_A, 902, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_Z, 985, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, 426, check)
      call createCurrent(P_Z, P_GMinus, P_G0, P_WPlus, 635, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_A, 1112, check)
      call createCurrent(P_WPlus, P_Z, P_H, P_GMinus, 1044, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_A, 715, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_G0, 235, check)
      call createCurrent(P_G0, P_muMinus, P_muPlus, 307, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, 448, check)
      call createCurrent(P_WMinus, P_nu_e, P_ePlus, 337, check)
      call createCurrent(P_sAnti, P_s, P_H, 326, check)
      call createCurrent(P_H, P_WMinus, P_H, P_WPlus, 137, check)
      call createCurrent(P_A, P_H, P_GMinus, P_WPlus, 1032, check)
      call createCurrent(P_t, P_bAnti, P_WMinus, 931, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_H, 596, check)
      call createCurrent(P_nu_mu, P_muPlus, P_WMinus, 202, check)
      call createCurrent(P_A, P_G0, P_WPlus, P_GMinus, 547, check)
      call createCurrent(P_ghGAnti, P_g, P_ghG, 729, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, 692, check)
      call createCurrent(P_eMinus, P_A, P_ePlus, 534, check)
      call createCurrent(P_d, P_A, P_dAnti, 172, check)
      call createCurrent(P_g, P_H, P_H, P_g, 1187, check)
      call createCurrent(P_s, P_cAnti, P_WPlus, 248, check)
      call createCurrent(P_Z, P_uAnti, P_u, 559, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_Z, 365, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, P_A, 347, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_G0, 175, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, P_Z, 105, check)
      call createCurrent(P_muPlus, P_muMinus, P_G0, 765, check)
      call createCurrent(P_G0, P_A, P_H, 1113, check)
      call createCurrent(P_nu_tauAnti, P_Z, P_nu_tau, 430, check)
      call createCurrent(P_GPlus, P_nu_muAnti, P_muMinus, 566, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_H, 846, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, 806, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, 170, check)
      call createCurrent(P_GPlus, P_H, P_GMinus, P_H, 563, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, 580, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, 231, check)
      call createCurrent(P_GPlus, P_H, P_H, P_GMinus, 13, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_G0, 312, check)
      call createCurrent(P_dAnti, P_g, P_d, 585, check)
      call createCurrent(P_Z, P_A, P_Z, P_Z, 1232, check)
      call createCurrent(P_s, P_sAnti, P_G0, 593, check)
      call createCurrent(P_nu_eAnti, P_nu_e, 1117, check)
      call createCurrent(P_GMinus, P_GPlus, P_H, 454, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WPlus, 656, check)
      call createCurrent(P_WPlus, P_b, P_tAnti, 2, check)
      call createCurrent(P_A, P_GMinus, P_A, P_GPlus, 197, check)
      call createCurrent(P_nu_e, P_A, P_nu_eAnti, 1092, check)
      call createCurrent(P_dAnti, P_u, P_GMinus, 992, check)
      call createCurrent(P_c, P_cAnti, P_A, 67, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, 950, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, 595, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_H, 739, check)
      call createCurrent(P_H, P_GPlus, P_Z, P_WMinus, 313, check)
      call createCurrent(P_sAnti, P_s, P_A, 286, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, 530, check)
      call createCurrent(P_nu_muAnti, P_Z, P_nu_mu, 638, check)
      call createCurrent(P_H, P_ghWm, P_ghWmAnti, 0, check)
      call createCurrent(P_G0, P_Z, 1077, check)
      call createCurrent(P_A, P_A, P_WPlus, P_WMinus, 254, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_A, 476, check)
      call createCurrent(P_A, P_eMinus, P_ePlus, 1, check)
      call createCurrent(P_WPlus, P_g, P_WMinus, P_g, 1181, check)
      call createCurrent(P_eMinus, P_ePlus, P_Z, 808, check)
      call createCurrent(P_WMinus, P_Z, P_A, P_WPlus, 747, check)
      call createCurrent(P_WPlus, P_WMinus, P_g, P_g, 1219, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, 144, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, 276, check)
      call createCurrent(P_G0, P_Z, P_GPlus, P_WMinus, 360, check)
      call createCurrent(P_b, P_tAnti, P_GPlus, 640, check)
      call createCurrent(P_tAnti, P_t, P_A, 252, check)
      call createCurrent(P_G0, P_G0, P_WPlus, P_WMinus, 74, check)
      call createCurrent(P_A, P_Z, P_H, P_H, 1127, check)
      call createCurrent(P_muMinus, P_A, P_muPlus, 314, check)
      call createCurrent(P_GMinus, P_ePlus, P_nu_e, 88, check)
      call createCurrent(P_u, P_uAnti, P_H, 84, check)
      call createCurrent(P_G0, P_A, P_GPlus, P_WMinus, 271, check)
      call createCurrent(P_Z, P_g, P_g, P_Z, 1163, check)
      call createCurrent(P_G0, P_Z, P_A, P_G0, 1068, check)
      call createCurrent(P_sAnti, P_G0, P_s, 147, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, 42, check)
      call createCurrent(P_nu_mu, P_A, P_nu_muAnti, 1109, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_A, 689, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_H, 671, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, 724, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_H, 257, check)
      call createCurrent(P_A, P_g, P_g, P_A, 1229, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_G0, 538, check)
      call createCurrent(P_c, P_sAnti, P_WMinus, 452, check)
      call createCurrent(P_GPlus, P_WMinus, P_WPlus, P_GMinus, 53, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, 688, check)
      call createCurrent(P_G0, P_bAnti, P_b, 17, check)
      call createCurrent(P_A, P_d, P_dAnti, 583, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, 27, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_Z, 686, check)
      call createCurrent(P_g, P_A, P_g, P_A, 1160, check)
      call createCurrent(P_H, P_WPlus, P_WMinus, 890, check)
      call createCurrent(P_GPlus, P_tauMinus, P_nu_tauAnti, 1003, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_A, 475, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, 315, check)
      call createCurrent(P_H, P_H, P_H, 646, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_A, 1085, check)
      call createCurrent(P_G0, P_ghWp, P_ghWpAnti, 537, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, 967, check)
      call createCurrent(P_GMinus, P_G0, P_G0, P_GPlus, 799, check)
      call createCurrent(P_ePlus, P_WMinus, P_nu_e, 845, check)
      call createCurrent(P_ghWpAnti, P_H, P_ghWp, 784, check)
      call createCurrent(P_WMinus, P_WPlus, P_H, P_H, 497, check)
      call createCurrent(P_Z, P_H, P_Z, 1000, check)
      call createCurrent(P_ePlus, P_H, P_eMinus, 442, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, P_A, 334, check)
      call createCurrent(P_A, P_A, P_A, P_Z, 1244, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, 532, check)
      call createCurrent(P_GMinus, P_tauPlus, P_nu_tau, 634, check)
      call createCurrent(P_A, P_g, P_A, P_g, 1149, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_Z, 862, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, P_Z, 685, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, P_Z, 743, check)
      call createCurrent(P_A, P_sAnti, P_s, 776, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_A, 33, check)
      call createCurrent(P_H, P_A, P_H, P_A, 1179, check)
      call createCurrent(P_WPlus, P_G0, P_WMinus, P_G0, 702, check)
      call createCurrent(P_H, P_H, P_G0, P_G0, 561, check)
      call createCurrent(P_sAnti, P_A, P_s, 120, check)
      call createCurrent(P_GMinus, P_GPlus, P_WMinus, P_WPlus, 173, check)
      call createCurrent(P_A, P_G0, P_H, 1086, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_A, 855, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, 517, check)
      call createCurrent(P_GPlus, P_WPlus, P_WMinus, P_GMinus, 316, check)
      call createCurrent(P_ghWm, P_H, P_ghWmAnti, 703, check)
      call createCurrent(P_A, P_GMinus, P_G0, P_WPlus, 531, check)
      call createCurrent(P_WMinus, P_GPlus, P_WPlus, P_GMinus, 392, check)
      call createCurrent(P_g, P_A, P_Z, P_g, 1199, check)
      call createCurrent(P_G0, P_g, P_G0, P_g, 1242, check)
      call createCurrent(P_GMinus, P_GPlus, P_WPlus, P_WMinus, 597, check)
      call createCurrent(P_d, P_dAnti, P_Z, 520, check)
      call createCurrent(P_ePlus, P_eMinus, P_Z, 603, check)
      call createCurrent(P_A, P_G0, P_GMinus, P_WPlus, 682, check)
      call createCurrent(P_dAnti, P_H, P_d, 111, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, P_Z, 906, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, 869, check)
      call createCurrent(P_WMinus, P_A, P_A, P_WPlus, 752, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_A, 971, check)
      call createCurrent(P_A, P_G0, P_Z, P_G0, 1093, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_H, 192, check)
      call createCurrent(P_t, P_tAnti, P_H, 94, check)
      call createCurrent(P_A, P_g, P_g, P_g, 1247, check)
      call createCurrent(P_Z, P_WPlus, P_H, P_GMinus, 1020, check)
      call createCurrent(P_A, P_g, P_Z, P_g, 1195, check)
      call createCurrent(P_WPlus, P_tAnti, P_b, 34, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, 1119, check)
      call createCurrent(P_Z, P_dAnti, P_d, 963, check)
      call createCurrent(P_g, P_g, P_G0, P_G0, 1222, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_H, 779, check)
      call createCurrent(P_tAnti, P_H, P_t, 40, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, 58, check)
      call createCurrent(P_g, P_g, P_g, P_A, 1184, check)
      call createCurrent(P_A, P_nu_muAnti, P_nu_mu, 1057, check)
      call createCurrent(P_nu_eAnti, P_WPlus, P_eMinus, 954, check)
      call createCurrent(P_cAnti, P_s, P_GPlus, 199, check)
      call createCurrent(P_G0, P_A, P_GMinus, P_WPlus, 883, check)
      call createCurrent(P_Z, P_A, P_g, P_g, 1154, check)
      call createCurrent(P_Z, P_H, P_GPlus, P_WMinus, 891, check)
      call createCurrent(P_c, P_g, P_cAnti, 496, check)
      call createCurrent(P_A, P_Z, P_Z, P_Z, 1148, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_A, 70, check)
      call createCurrent(P_Z, P_Z, P_A, P_Z, 1230, check)
      call createCurrent(P_g, P_g, P_g, P_Z, 1211, check)
      call createCurrent(P_Z, P_WMinus, P_Z, P_WPlus, 479, check)
      call createCurrent(P_Z, P_GMinus, P_A, P_GPlus, 578, check)
      call createCurrent(P_c, P_cAnti, P_Z, 80, check)
      call createCurrent(P_tauPlus, P_tauMinus, 1058, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_G0, 649, check)
      call createCurrent(P_A, P_ePlus, P_eMinus, 553, check)
      call createCurrent(P_uAnti, P_u, P_g, 233, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, 605, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, 417, check)
      call createCurrent(P_A, P_A, P_H, P_H, 1188, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, 433, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, 390, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, 23, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_Z, 835, check)
      call createCurrent(P_WMinus, P_G0, P_WPlus, P_G0, 839, check)
      call createCurrent(P_Z, P_muPlus, P_muMinus, 863, check)
      call createCurrent(P_A, P_dAnti, P_d, 238, check)
      call createCurrent(P_cAnti, P_c, 1105, check)
      call createCurrent(P_GMinus, P_H, P_A, P_WPlus, 398, check)
      call createCurrent(P_WPlus, P_WMinus, P_H, 267, check)
      call createCurrent(P_H, P_ghZ, P_ghZAnti, 798, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_Z, 749, check)
      call createCurrent(P_sAnti, P_H, P_s, 1009, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, P_A, 180, check)
      call createCurrent(P_ghGAnti, P_ghG, P_g, 663, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, 587, check)
      call createCurrent(P_H, P_A, P_Z, P_H, 1054, check)
      call createCurrent(P_dAnti, P_Z, P_d, 576, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_A, 885, check)
      call createCurrent(P_WMinus, P_H, P_A, P_GPlus, 815, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_A, 709, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, 220, check)
      call createCurrent(P_H, P_g, P_g, P_H, 1213, check)
      call createCurrent(P_muMinus, P_Z, P_muPlus, 31, check)
      call createCurrent(P_G0, P_G0, P_WMinus, P_WPlus, 679, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, 1067, check)
      call createCurrent(P_Z, P_G0, P_WPlus, P_GMinus, 677, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, 874, check)
      call createCurrent(P_Z, P_nu_mu, P_nu_muAnti, 651, check)
      call createCurrent(P_b, P_bAnti, P_A, 362, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, 43, check)
      call createCurrent(P_A, P_G0, 1087, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, P_A, 551, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_G0, 419, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_Z, 311, check)
      call createCurrent(P_sAnti, P_WMinus, P_c, 423, check)
      call createCurrent(P_uAnti, P_u, P_G0, 1048, check)
      call createCurrent(P_GPlus, P_tAnti, P_b, 528, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_A, 101, check)
      call createCurrent(P_H, P_A, P_H, P_Z, 1135, check)
      call createCurrent(P_H, P_H, P_GMinus, P_GPlus, 345, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_H, 90, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, 451, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, 721, check)
      call createCurrent(P_g, P_g, P_g, P_g, 672, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_Z, 854, check)
      call createCurrent(P_tAnti, P_b, P_WPlus, 274, check)
      call createCurrent(P_WMinus, P_G0, P_Z, P_GPlus, 942, check)
      call createCurrent(P_Z, P_g, P_g, P_A, 1193, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, 1040, check)
      call createCurrent(P_g, P_WPlus, P_g, P_WMinus, 1158, check)
      call createCurrent(P_A, P_H, P_G0, 1116, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WPlus, 121, check)
      call createCurrent(P_H, P_GPlus, P_A, P_WMinus, 853, check)
      call createCurrent(P_Z, P_GPlus, P_G0, P_WMinus, 225, check)
      call createCurrent(P_H, P_Z, P_WPlus, P_GMinus, 881, check)
      call createCurrent(P_uAnti, P_A, P_u, 962, check)
      call createCurrent(P_Z, P_g, P_A, P_g, 1223, check)
      call createCurrent(P_g, P_WMinus, P_WPlus, P_g, 1183, check)
      call createCurrent(P_G0, P_GPlus, P_Z, P_WMinus, 979, check)
      call createCurrent(P_WPlus, P_GMinus, P_WMinus, P_GPlus, 826, check)
      call createCurrent(P_A, P_Z, P_A, P_A, 1245, check)
      call createCurrent(P_muPlus, P_nu_mu, P_WMinus, 990, check)
      call createCurrent(P_uAnti, P_WPlus, P_d, 735, check)
      call createCurrent(P_Z, P_A, P_GMinus, P_GPlus, 200, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_GMinus, 665, check)
      call createCurrent(P_g, P_Z, P_Z, P_g, 1241, check)
      call createCurrent(P_Z, P_H, P_WMinus, P_GPlus, 93, check)
      call createCurrent(P_G0, P_H, P_G0, 860, check)
      call createCurrent(P_G0, P_A, P_Z, P_G0, 1056, check)
      call createCurrent(P_WPlus, P_A, P_Z, P_WMinus, 108, check)
      call createCurrent(P_A, P_A, P_A, P_A, 1203, check)
      call createCurrent(P_Z, P_bAnti, P_b, 1023, check)
      call createCurrent(P_H, P_Z, P_H, P_A, 1080, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_Z, 393, check)
      call createCurrent(P_WMinus, P_GPlus, P_GMinus, P_WPlus, 601, check)
      call createCurrent(P_t, P_WMinus, P_bAnti, 674, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_Z, 358, check)
      call createCurrent(P_Z, P_A, P_Z, P_A, 1157, check)
      call createCurrent(P_A, P_H, P_WMinus, P_GPlus, 4, check)
      call createCurrent(P_g, P_g, P_A, P_g, 1227, check)
      call createCurrent(P_G0, P_G0, P_G0, P_G0, 947, check)
      call createCurrent(P_G0, P_Z, P_WPlus, P_GMinus, 519, check)
      call createCurrent(P_sAnti, P_c, P_GMinus, 783, check)
      call createCurrent(P_H, P_d, P_dAnti, 655, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_Z, 441, check)
      call createCurrent(P_Z, P_Z, P_GMinus, P_GPlus, 132, check)
      call createCurrent(P_GMinus, P_nu_tau, P_tauPlus, 807, check)
      call createCurrent(P_WMinus, P_t, P_bAnti, 75, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_A, 889, check)
      call createCurrent(P_c, P_cAnti, P_G0, 72, check)
      call createCurrent(P_muPlus, P_H, P_muMinus, 790, check)
      call createCurrent(P_GPlus, P_eMinus, P_nu_eAnti, 1022, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, 1033, check)
      call createCurrent(P_A, P_nu_eAnti, P_nu_e, 1082, check)
      call createCurrent(P_H, P_muMinus, P_muPlus, 495, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, 884, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_G0, 422, check)
      call createCurrent(P_WMinus, P_Z, P_Z, P_WPlus, 428, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_H, 1030, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_G0, 546, check)
      call createCurrent(P_H, P_GMinus, P_H, P_GPlus, 575, check)
      call createCurrent(P_WMinus, P_H, P_WPlus, 425, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, 69, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, 36, check)
      call createCurrent(P_Z, P_G0, P_Z, P_G0, 820, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, 704, check)
      call createCurrent(P_c, P_GMinus, P_sAnti, 474, check)
      call createCurrent(P_ePlus, P_nu_e, P_GMinus, 136, check)
      call createCurrent(P_H, P_WPlus, P_H, P_WMinus, 831, check)
      call createCurrent(P_bAnti, P_A, P_b, 492, check)
      call createCurrent(P_s, P_GPlus, P_cAnti, 968, check)
      call createCurrent(P_WMinus, P_H, P_WPlus, P_H, 727, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, 550, check)
      call createCurrent(P_WPlus, P_muMinus, P_nu_muAnti, 151, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, 972, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, 959, check)
      call createCurrent(P_nu_eAnti, P_Z, P_nu_e, 318, check)
      call createCurrent(P_dAnti, P_d, P_g, 357, check)
      call createCurrent(P_Z, P_H, P_G0, 1002, check)
      call createCurrent(P_WMinus, P_GMinus, P_WPlus, P_GPlus, 288, check)
      call createCurrent(P_WMinus, P_G0, P_A, P_GPlus, 133, check)
      call createCurrent(P_A, P_A, P_g, P_g, 1162, check)
      call createCurrent(P_bAnti, P_g, P_b, 882, check)
      call createCurrent(P_b, P_Z, P_bAnti, 980, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, 3, check)
      call createCurrent(P_cAnti, P_WPlus, P_s, 609, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, P_A, 999, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, 515, check)
      call createCurrent(P_WPlus, P_uAnti, P_d, 1004, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, 223, check)
      call createCurrent(P_u, P_uAnti, 1078, check)
      call createCurrent(P_A, P_G0, P_G0, P_A, 1226, check)
      call createCurrent(P_G0, P_sAnti, P_s, 887, check)
      call createCurrent(P_WMinus, P_g, P_g, P_WPlus, 1205, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_A, 212, check)
      call createCurrent(P_GPlus, P_s, P_cAnti, 403, check)
      call createCurrent(P_d, P_uAnti, P_WPlus, 356, check)
      call createCurrent(P_muMinus, P_H, P_muPlus, 124, check)
      call createCurrent(P_Z, P_Z, P_G0, P_G0, 217, check)
      call createCurrent(P_A, P_H, P_GPlus, P_WMinus, 382, check)
      call createCurrent(P_uAnti, P_GPlus, P_d, 110, check)
      call createCurrent(P_GPlus, P_WPlus, P_GMinus, P_WMinus, 65, check)
      call createCurrent(P_tauPlus, P_WMinus, P_nu_tau, 923, check)
      call createCurrent(P_Z, P_Z, 1097, check)
      call createCurrent(P_b, P_tAnti, P_WPlus, 570, check)
      call createCurrent(P_g, P_g, P_WPlus, P_WMinus, 1243, check)
      call createCurrent(P_nu_muAnti, P_GPlus, P_muMinus, 873, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, 57, check)
      call createCurrent(P_sAnti, P_s, P_Z, 838, check)
      call createCurrent(P_uAnti, P_Z, P_u, 490, check)
      call createCurrent(P_H, P_GPlus, P_GMinus, 71, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, P_Z, 1047, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, 449, check)
      call createCurrent(P_GPlus, P_Z, P_A, P_GMinus, 834, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, 780, check)
      call createCurrent(P_g, P_uAnti, P_u, 1021, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, 46, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_A, 572, check)
      call createCurrent(P_g, P_g, 1083, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, 28, check)
      call createCurrent(P_Z, P_H, P_Z, P_H, 590, check)
      call createCurrent(P_d, P_dAnti, 1104, check)
      call createCurrent(P_A, P_G0, P_A, P_G0, 1221, check)
      call createCurrent(P_muMinus, P_G0, P_muPlus, 514, check)
      call createCurrent(P_g, P_Z, P_g, P_Z, 1186, check)
      call createCurrent(P_g, P_g, P_Z, P_g, 1153, check)
      call createCurrent(P_c, P_Z, P_cAnti, 817, check)
      call createCurrent(P_WMinus, P_WPlus, 1069, check)
      call createCurrent(P_Z, P_sAnti, P_s, 49, check)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, 323, check)
      call createCurrent(P_G0, P_b, P_bAnti, 51, check)
      call createCurrent(P_nu_mu, P_GMinus, P_muPlus, 324, check)
      call createCurrent(P_H, P_eMinus, P_ePlus, 948, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_H, 1010, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_H, 1017, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, 847, check)
      call createCurrent(P_H, P_G0, P_Z, 140, check)
      call createCurrent(P_Z, P_nu_e, P_nu_eAnti, 209, check)
      call createCurrent(P_G0, P_WMinus, P_A, P_GPlus, 266, check)
      call createCurrent(P_GPlus, P_G0, P_G0, P_GMinus, 44, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, 741, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, 355, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_G0, 395, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_G0, 501, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, 693, check)
      call createCurrent(P_WMinus, P_GPlus, 1076, check)
      call createCurrent(P_WMinus, P_nu_tau, P_tauPlus, 932, check)
      call createCurrent(P_H, P_GPlus, P_H, P_GMinus, 920, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, 708, check)
      call createCurrent(P_Z, P_G0, P_G0, P_Z, 183, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_Z, 484, check)
      call createCurrent(P_WMinus, P_WPlus, P_G0, P_G0, 116, check)
      call createCurrent(P_muPlus, P_Z, P_muMinus, 694, check)
      call createCurrent(P_WMinus, P_A, P_Z, P_WPlus, 940, check)
      call createCurrent(P_G0, P_G0, P_A, P_A, 1168, check)
      call createCurrent(P_GMinus, P_Z, P_Z, P_GPlus, 696, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, 250, check)
      call createCurrent(P_A, P_A, P_Z, P_A, 1235, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, 507, check)
      call createCurrent(P_A, P_GPlus, P_Z, P_GMinus, 810, check)
      call createCurrent(P_GMinus, P_G0, P_A, P_WPlus, 627, check)
      call createCurrent(P_WPlus, P_WMinus, P_WPlus, P_WMinus, 736, check)
      call createCurrent(P_tAnti, P_t, 1132, check)
      call createCurrent(P_GMinus, P_GPlus, P_g, P_g, 1218, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, 10, check)
      call createCurrent(P_nu_tau, P_Z, P_nu_tauAnti, 618, check)
      call createCurrent(P_G0, P_d, P_dAnti, 813, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, 787, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_A, 594, check)
      call createCurrent(P_bAnti, P_G0, P_b, 375, check)
      call createCurrent(P_GMinus, P_G0, P_Z, P_WPlus, 930, check)
      call createCurrent(P_H, P_Z, P_A, P_H, 1070, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_A, 127, check)
      call createCurrent(P_Z, P_Z, P_WPlus, P_WMinus, 630, check)
      call createCurrent(P_WPlus, P_WMinus, P_G0, P_G0, 536, check)
      call createCurrent(P_G0, P_G0, P_GMinus, P_GPlus, 236, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, P_A, 750, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_G0, 1045, check)
      call createCurrent(P_H, P_Z, P_G0, 966, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_H, 434, check)
      call createCurrent(P_GPlus, P_GMinus, P_H, 154, check)
      call createCurrent(P_A, P_nu_e, P_nu_eAnti, 1144, check)
      call createCurrent(P_c, P_cAnti, P_H, 987, check)
      call createCurrent(P_u, P_uAnti, P_A, 983, check)
      call createCurrent(P_A, P_A, P_GMinus, P_GPlus, 922, check)
      call createCurrent(P_GPlus, P_nu_eAnti, P_eMinus, 770, check)
      call createCurrent(P_Z, P_H, P_H, P_A, 1118, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, P_Z, 471, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, 764, check)
      call createCurrent(P_Z, P_cAnti, P_c, 171, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_G0, 740, check)
      call createCurrent(P_muPlus, P_G0, P_muMinus, 738, check)
      call createCurrent(P_nu_eAnti, P_A, P_nu_e, 1071, check)
      call createCurrent(P_nu_tauAnti, P_WPlus, P_tauMinus, 486, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_A, 742, check)
      call createCurrent(P_bAnti, P_Z, P_b, 100, check)
      call createCurrent(P_H, P_G0, P_G0, P_H, 273, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_A, 418, check)
      call createCurrent(P_A, P_Z, P_G0, P_G0, 1062, check)
      call createCurrent(P_WPlus, P_eMinus, P_nu_eAnti, 875, check)
      call createCurrent(P_tAnti, P_WPlus, P_b, 164, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, 625, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_Z, 162, check)
      call createCurrent(P_G0, P_tauPlus, P_tauMinus, 284, check)
      call createCurrent(P_Z, P_nu_tauAnti, P_nu_tau, 774, check)
      call createCurrent(P_cAnti, P_H, P_c, 573, check)
      call createCurrent(P_d, P_dAnti, P_A, 376, check)
      call createCurrent(P_WMinus, P_Z, P_G0, P_GPlus, 901, check)
      call createCurrent(P_A, P_Z, 1098, check)
      call createCurrent(P_s, P_G0, P_sAnti, 218, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, 283, check)
      call createCurrent(P_G0, P_G0, P_H, 676, check)
      call createCurrent(P_tauPlus, P_GMinus, P_nu_tau, 767, check)
      call createCurrent(P_u, P_H, P_uAnti, 678, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, 668, check)
      call createCurrent(P_H, P_A, P_GPlus, P_WMinus, 797, check)
      call createCurrent(P_s, P_cAnti, P_GPlus, 208, check)
      call createCurrent(P_G0, P_A, P_A, P_G0, 1206, check)
      call createCurrent(P_cAnti, P_c, P_A, 5, check)
      call createCurrent(P_eMinus, P_ePlus, 1139, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, 617, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_Z, 1037, check)
      call createCurrent(P_c, P_cAnti, 1101, check)
      call createCurrent(P_WPlus, P_s, P_cAnti, 368, check)
      call createCurrent(P_H, P_A, P_Z, 1063, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, 577, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, 353, check)
      call createCurrent(P_H, P_muPlus, P_muMinus, 606, check)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, 802, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, 641, check)
      call createCurrent(P_u, P_uAnti, P_G0, 915, check)
      call createCurrent(P_WPlus, P_WMinus, 1072, check)
      call createCurrent(P_tauMinus, P_G0, P_tauPlus, 604, check)
      call createCurrent(P_G0, P_Z, P_WMinus, P_GPlus, 650, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_H, 695, check)
      call createCurrent(P_bAnti, P_H, P_b, 667, check)
      call createCurrent(P_nu_tauAnti, P_A, P_nu_tau, 1095, check)
      call createCurrent(P_G0, P_GMinus, P_G0, P_GPlus, 832, check)
      call createCurrent(P_Z, P_g, P_g, P_g, 1164, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_H, 760, check)
      call createCurrent(P_Z, P_Z, P_H, P_H, 796, check)
      call createCurrent(P_g, P_GPlus, P_GMinus, P_g, 1150, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, 394, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghWp, 857, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_A, 1050, check)
      call createCurrent(P_uAnti, P_H, P_u, 903, check)
      call createCurrent(P_GMinus, P_nu_e, P_ePlus, 167, check)
      call createCurrent(P_Z, P_A, P_A, P_Z, 1214, check)
      call createCurrent(P_g, P_s, P_sAnti, 827, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_G0, 300, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, 285, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, 539, check)
      call createCurrent(P_GPlus, P_GMinus, P_WMinus, P_WPlus, 842, check)
      call createCurrent(P_WMinus, P_ePlus, P_nu_e, 14, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, 427, check)
      call createCurrent(P_b, P_bAnti, 1124, check)
      call createCurrent(P_WPlus, P_G0, P_Z, P_GMinus, 893, check)
      call createCurrent(P_H, P_Z, P_H, P_Z, 975, check)
      call createCurrent(P_muPlus, P_A, P_muMinus, 886, check)
      call createCurrent(P_WMinus, P_A, P_G0, P_GPlus, 925, check)
      call createCurrent(P_tauMinus, P_tauPlus, 1060, check)
      call createCurrent(P_WMinus, P_A, P_H, P_GPlus, 444, check)
      call createCurrent(P_GPlus, P_A, P_A, P_GMinus, 99, check)
      call createCurrent(P_t, P_tAnti, 1049, check)
      call createCurrent(P_G0, P_WPlus, P_G0, P_WMinus, 367, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, 555, check)
      call createCurrent(P_eMinus, P_GPlus, P_nu_eAnti, 608, check)
      call createCurrent(P_c, P_A, P_cAnti, 226, check)
      call createCurrent(P_GPlus, P_d, P_uAnti, 756, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, 872, check)
      call createCurrent(P_GPlus, P_Z, P_G0, P_WMinus, 76, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, 214, check)
      call createCurrent(P_ghWp, P_H, P_ghWpAnti, 321, check)
      call createCurrent(P_dAnti, P_d, P_H, 406, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_A, 66, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_H, 782, check)
      call createCurrent(P_tauPlus, P_Z, P_tauMinus, 628, check)
      call createCurrent(P_d, P_G0, P_dAnti, 340, check)
      call createCurrent(P_bAnti, P_t, P_WMinus, 1031, check)
      call createCurrent(P_s, P_WPlus, P_cAnti, 302, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, 562, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_G0, 96, check)
      call createCurrent(P_A, P_H, P_A, 1156, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, 349, check)
      call createCurrent(P_dAnti, P_WMinus, P_u, 737, check)
      call createCurrent(P_A, P_G0, P_GPlus, P_WMinus, 205, check)
      call createCurrent(P_Z, P_A, P_WMinus, P_WPlus, 245, check)
      call createCurrent(P_Z, P_A, P_H, 1106, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, 467, check)
      call createCurrent(P_A, P_GPlus, P_A, P_GMinus, 157, check)
      call createCurrent(P_A, P_Z, P_GMinus, P_GPlus, 766, check)
      call createCurrent(P_A, P_H, P_H, P_Z, 1055, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, 102, check)
      call createCurrent(P_GMinus, P_g, P_g, P_GPlus, 1201, check)
      call createCurrent(P_cAnti, P_GPlus, P_s, 637, check)
      call createCurrent(P_eMinus, P_G0, P_ePlus, 239, check)
      call createCurrent(P_uAnti, P_u, P_A, 436, check)
      call createCurrent(P_tAnti, P_G0, P_t, 461, check)
      call createCurrent(P_A, P_tAnti, P_t, 581, check)
      call createCurrent(P_GPlus, P_A, P_H, P_WMinus, 1028, check)
      call createCurrent(P_t, P_G0, P_tAnti, 935, check)
      call createCurrent(P_G0, P_A, P_G0, P_A, 1228, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, 117, check)
      call createCurrent(P_u, P_g, P_uAnti, 991, check)
      call createCurrent(P_muPlus, P_nu_mu, P_GMinus, 464, check)
      call createCurrent(P_s, P_H, P_sAnti, 512, check)
      call createCurrent(P_Z, P_nu_eAnti, P_nu_e, 85, check)
      call createCurrent(P_GPlus, P_uAnti, P_d, 864, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, 216, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, 186, check)
      call createCurrent(P_tAnti, P_Z, P_t, 1013, check)
      call createCurrent(P_tauMinus, P_H, P_tauPlus, 592, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, 850, check)
      call createCurrent(P_WMinus, P_u, P_dAnti, 400, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_WMinus, 129, check)
      call createCurrent(P_G0, P_GMinus, P_Z, P_WPlus, 191, check)
      call createCurrent(P_G0, P_Z, P_Z, P_G0, 681, check)
      call createCurrent(P_Z, P_d, P_dAnti, 485, check)
      call createCurrent(P_G0, P_WMinus, P_WPlus, P_G0, 1034, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_G0, 622, check)
      call createCurrent(P_Z, P_A, P_A, P_A, 1239, check)
      call createCurrent(P_GMinus, P_nu_mu, P_muPlus, 472, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_Z, 91, check)
      call createCurrent(P_g, P_g, P_A, P_Z, 1240, check)
      call createCurrent(P_d, P_dAnti, P_H, 905, check)
      call createCurrent(P_Z, P_WMinus, P_H, P_GPlus, 723, check)
      call createCurrent(P_Z, P_GMinus, P_H, P_WPlus, 697, check)
      call createCurrent(P_GPlus, P_g, P_GMinus, P_g, 1165, check)
      call createCurrent(P_H, P_H, P_H, P_H, 801, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Z, 1035, check)
      call createCurrent(P_G0, P_WPlus, P_WMinus, P_G0, 705, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, 1036, check)
      call createCurrent(P_b, P_bAnti, P_g, 771, check)
      call createCurrent(P_A, P_muMinus, P_muPlus, 711, check)
      call createCurrent(P_A, P_Z, P_WMinus, P_WPlus, 502, check)
      call createCurrent(P_WMinus, P_tauPlus, P_nu_tau, 859, check)
      call createCurrent(P_GMinus, P_WMinus, P_GPlus, P_WPlus, 56, check)
      call createCurrent(P_WPlus, P_Z, P_Z, P_WMinus, 965, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, 55, check)
      call createCurrent(P_G0, P_G0, P_g, P_g, 1152, check)
      call createCurrent(P_nu_mu, P_WMinus, P_muPlus, 493, check)
      call createCurrent(P_A, P_s, P_sAnti, 342, check)
      call createCurrent(P_Z, P_H, P_H, P_Z, 718, check)
      call createCurrent(P_b, P_A, P_bAnti, 396, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_Z, 945, check)
      call createCurrent(P_WMinus, P_WPlus, P_WPlus, P_WMinus, 509, check)
      call createCurrent(P_GMinus, P_c, P_sAnti, 866, check)
      call createCurrent(P_H, P_ePlus, P_eMinus, 977, check)
      call createCurrent(P_WPlus, P_H, P_Z, P_GMinus, 888, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, 142, check)
      call createCurrent(P_bAnti, P_b, P_Z, 1027, check)
      call createCurrent(P_g, P_A, P_g, P_g, 1210, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WPlus, 325, check)
      call createCurrent(P_A, P_A, P_WMinus, P_WPlus, 282, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, 45, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_Z, 201, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_H, 1038, check)
      call createCurrent(P_A, P_WMinus, P_Z, P_WPlus, 567, check)
      call createCurrent(P_A, P_H, P_Z, 1143, check)
      call createCurrent(P_GMinus, P_H, P_GPlus, P_H, 25, check)
      call createCurrent(P_A, P_H, P_WPlus, P_GMinus, 244, check)
      call createCurrent(P_d, P_g, P_dAnti, 174, check)
      call createCurrent(P_WPlus, P_WMinus, P_GPlus, P_GMinus, 125, check)
      call createCurrent(P_g, P_t, P_tAnti, 777, check)
      call createCurrent(P_G0, P_Z, P_G0, P_Z, 450, check)
      call createCurrent(P_H, P_tAnti, P_t, 812, check)
      call createCurrent(P_g, P_A, P_A, P_g, 1174, check)
      call createCurrent(P_cAnti, P_s, P_WPlus, 104, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, 944, check)
      call createCurrent(P_WPlus, P_g, P_g, P_WMinus, 1171, check)
      call createCurrent(P_sAnti, P_Z, P_s, 843, check)
      call createCurrent(P_GPlus, P_muMinus, P_nu_muAnti, 763, check)
      call createCurrent(P_A, P_Z, P_H, 1126, check)
      call createCurrent(P_g, P_g, P_WMinus, P_WPlus, 1159, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, 527, check)
      call createCurrent(P_GMinus, P_WPlus, 1114, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_A, 1024, check)
      call createCurrent(P_H, P_A, P_A, 1231, check)
      call createCurrent(P_G0, P_H, P_G0, P_H, 211, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, 858, check)
      call createCurrent(P_GMinus, P_GMinus, P_GPlus, P_GPlus, 480, check)
      call createCurrent(P_A, P_WPlus, P_H, P_GMinus, 35, check)
      call createCurrent(P_A, P_Z, P_WPlus, P_WMinus, 552, check)
      call createCurrent(P_nu_e, P_Z, P_nu_eAnti, 327, check)
      call createCurrent(P_Z, P_muMinus, P_muPlus, 107, check)
      call createCurrent(P_c, P_cAnti, P_g, 296, check)
      call createCurrent(P_dAnti, P_d, P_A, 203, check)
      call createCurrent(P_G0, P_GPlus, P_G0, P_GMinus, 153, check)
      call createCurrent(P_dAnti, P_u, P_WMinus, 584, check)
      call createCurrent(P_uAnti, P_d, P_GPlus, 588, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, P_A, 190, check)
      call createCurrent(P_u, P_uAnti, P_Z, 333, check)
      call createCurrent(P_GPlus, P_H, P_Z, P_WMinus, 996, check)
      call createCurrent(P_g, P_g, P_GPlus, P_GMinus, 1200, check)
      call createCurrent(P_WMinus, P_WPlus, P_H, 953, check)
      call createCurrent(P_GMinus, P_H, P_Z, P_WPlus, 410, check)
      call createCurrent(P_g, P_sAnti, P_s, 388, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_Z, 346, check)
      call createCurrent(P_bAnti, P_b, 1079, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_A, 386, check)
      call createCurrent(P_ePlus, P_nu_e, P_WMinus, 725, check)
      call createCurrent(P_H, P_WPlus, P_Z, P_GMinus, 184, check)
      call createCurrent(P_nu_muAnti, P_WPlus, P_muMinus, 397, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, 335, check)
      call createCurrent(P_dAnti, P_A, P_d, 146, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, 994, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_GPlus, 961, check)
      call createCurrent(P_A, P_t, P_tAnti, 97, check)
      call createCurrent(P_G0, P_tAnti, P_t, 964, check)
      call createCurrent(P_muPlus, P_WMinus, P_nu_mu, 624, check)
      call createCurrent(P_H, P_GMinus, P_A, P_WPlus, 253, check)
      call createCurrent(P_b, P_G0, P_bAnti, 79, check)
      call createCurrent(P_nu_tau, P_GMinus, P_tauPlus, 12, check)
      call createCurrent(P_Z, P_tAnti, P_t, 404, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_Z, 522, check)
      call createCurrent(P_G0, P_G0, 1099, check)
      call createCurrent(P_g, P_b, P_bAnti, 159, check)
      call createCurrent(P_A, P_b, P_bAnti, 297, check)
      call createCurrent(P_g, P_g, P_H, P_H, 1177, check)
      call createCurrent(P_ePlus, P_eMinus, P_G0, 130, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, 331, check)
      call createCurrent(P_G0, P_G0, P_Z, P_A, 1140, check)
      call createCurrent(P_tauMinus, P_GPlus, P_nu_tauAnti, 781, check)
      call createCurrent(P_Z, P_s, P_sAnti, 374, check)
      call createCurrent(P_nu_tau, P_WMinus, P_tauPlus, 255, check)
      call createCurrent(P_Z, P_WMinus, P_A, P_WPlus, 1014, check)
      call createCurrent(P_Z, P_t, P_tAnti, 206, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, 626, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, 645, check)
      call createCurrent(P_nu_e, P_ePlus, P_GMinus, 556, check)
      call createCurrent(P_GPlus, P_GMinus, P_GPlus, P_GMinus, 122, check)
      call createCurrent(P_A, P_A, P_Z, P_Z, 1202, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_A, 731, check)
      call createCurrent(P_c, P_H, P_cAnti, 598, check)
      call createCurrent(P_GPlus, P_WMinus, 1075, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_G0, 399, check)
      call createCurrent(P_Z, P_GPlus, P_Z, P_GMinus, 378, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_A, 487, check)
      call createCurrent(P_sAnti, P_s, P_g, 291, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_H, 822, check)
      call createCurrent(P_H, P_H, P_WMinus, P_WPlus, 262, check)
      call createCurrent(P_tAnti, P_b, P_GPlus, 361, check)
      call createCurrent(P_A, P_H, P_A, P_H, 1237, check)
      call createCurrent(P_u, P_dAnti, P_GMinus, 165, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, 730, check)
      call createCurrent(P_WPlus, P_WPlus, P_WMinus, P_WMinus, 938, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_Z, 145, check)
      call createCurrent(P_A, P_WPlus, P_G0, P_GMinus, 898, check)
      call createCurrent(P_WMinus, P_WMinus, P_WPlus, P_WPlus, 914, check)
      call createCurrent(P_g, P_Z, P_A, P_g, 1233, check)
      call createCurrent(P_A, P_nu_tauAnti, P_nu_tau, 1103, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_G0, 1042, check)
      call createCurrent(P_tAnti, P_GPlus, P_b, 758, check)
      call createCurrent(P_ePlus, P_eMinus, P_H, 413, check)
      call createCurrent(P_s, P_sAnti, 1102, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_GMinus, 700, check)
      call createCurrent(P_nu_e, P_nu_eAnti, 1096, check)
      call createCurrent(P_b, P_g, P_bAnti, 373, check)
      call createCurrent(P_tAnti, P_t, P_g, 755, check)
      call createCurrent(P_WPlus, P_WMinus, P_WMinus, P_WPlus, 207, check)
      call createCurrent(P_d, P_H, P_dAnti, 523, check)
      call createCurrent(P_WPlus, P_G0, P_G0, P_WMinus, 924, check)
      call createCurrent(P_WPlus, P_H, P_WMinus, P_H, 870, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, 982, check)
      call createCurrent(P_uAnti, P_u, P_Z, 943, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_Z, 1016, check)
      call createCurrent(P_ePlus, P_G0, P_eMinus, 852, check)
      call createCurrent(P_WMinus, P_WPlus, P_GPlus, P_GMinus, 352, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, 98, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, P_Z, 988, check)
      call createCurrent(P_G0, P_A, P_G0, P_Z, 1089, check)
      call createCurrent(P_H, P_GMinus, P_GPlus, 579, check)
      call createCurrent(P_WPlus, P_d, P_uAnti, 421, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, 833, check)
      call createCurrent(P_H, P_H, P_g, P_g, 1169, check)
      call createCurrent(P_G0, P_t, P_tAnti, 82, check)
      call createCurrent(P_sAnti, P_c, P_WMinus, 683, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, 654, check)
      call createCurrent(P_sAnti, P_s, P_G0, 64, check)
      call createCurrent(P_bAnti, P_t, P_GMinus, 21, check)
      call createCurrent(P_H, P_Z, P_GPlus, P_WMinus, 78, check)
      call createCurrent(P_WPlus, P_nu_tauAnti, P_tauMinus, 1041, check)
      call createCurrent(P_A, P_GMinus, P_H, P_WPlus, 259, check)
      call createCurrent(P_H, P_WMinus, P_Z, P_GPlus, 6, check)
      call createCurrent(P_A, P_WMinus, P_G0, P_GPlus, 181, check)
      call createCurrent(P_GMinus, P_WPlus, P_GPlus, P_WMinus, 558, check)
      call createCurrent(P_eMinus, P_ePlus, P_G0, 816, check)
      call createCurrent(P_u, P_G0, P_uAnti, 344, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_G0, 350, check)
      call createCurrent(P_cAnti, P_c, P_G0, 224, check)
      call createCurrent(P_g, P_u, P_uAnti, 359, check)
      call createCurrent(P_H, P_bAnti, P_b, 319, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, P_A, 261, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_H, 720, check)
      call createCurrent(P_WMinus, P_bAnti, P_t, 20, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, 919, check)
      call createCurrent(P_GMinus, P_A, P_Z, P_GPlus, 275, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, 791, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_A, 759, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_H, 114, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, 39, check)
      call createCurrent(P_A, P_G0, P_G0, P_Z, 1081, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, 408, check)
      call createCurrent(P_H, P_t, P_tAnti, 591, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, 958, check)
      call createCurrent(P_muMinus, P_GPlus, P_nu_muAnti, 803, check)
      call createCurrent(P_GPlus, P_Z, P_H, P_WMinus, 892, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, 957, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, 844, check)
      call createCurrent(P_WPlus, P_GPlus, P_WMinus, P_GMinus, 984, check)
      call createCurrent(P_H, P_dAnti, P_d, 86, check)
      call createCurrent(P_g, P_g, P_g, 568, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, 871, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_A, 952, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, 161, check)
      call createCurrent(P_GMinus, P_H, P_H, P_GPlus, 304, check)
      call createCurrent(P_eMinus, P_ePlus, P_A, 769, check)
      call createCurrent(P_nu_mu, P_Z, P_nu_muAnti, 287, check)
      call createCurrent(P_A, P_Z, P_A, P_Z, 1161, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_H, 916, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, 557, check)
      call createCurrent(P_sAnti, P_GMinus, P_c, 897, check)
      call createCurrent(P_H, P_u, P_uAnti, 488, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, 970, check)
      call createCurrent(P_GMinus, P_GPlus, P_GPlus, P_GMinus, 256, check)
      call createCurrent(P_GPlus, P_cAnti, P_s, 795, check)
      call createCurrent(P_u, P_WMinus, P_dAnti, 732, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_G0, 664, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, 956, check)
      call createCurrent(P_GMinus, P_Z, P_H, P_WPlus, 786, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, 669, check)
      call createCurrent(P_H, P_A, P_G0, 1065, check)
      call createCurrent(P_ghG, P_g, P_ghGAnti, 150, check)
      call createCurrent(P_g, P_WMinus, P_g, P_WPlus, 1234, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_GPlus, 642, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_H, 662, check)
      call createCurrent(P_H, P_s, P_sAnti, 411, check)
      call createCurrent(P_muPlus, P_muMinus, P_Z, 227, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, 106, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, 163, check)
      call createCurrent(P_H, P_c, P_cAnti, 459, check)
      call createCurrent(P_Z, P_GMinus, P_Z, P_GPlus, 198, check)
      call createCurrent(P_nu_eAnti, P_GPlus, P_eMinus, 908, check)
      call createCurrent(P_Z, P_H, P_GMinus, P_WPlus, 278, check)
      call createCurrent(P_tauMinus, P_Z, P_tauPlus, 748, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, 38, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, 230, check)
      call createCurrent(P_WMinus, P_Z, P_H, P_GPlus, 338, check)
      call createCurrent(P_Z, P_G0, P_H, 714, check)
      call createCurrent(P_g, P_dAnti, P_d, 911, check)
      call createCurrent(P_d, P_dAnti, P_G0, 615, check)
      call createCurrent(P_A, P_GMinus, P_Z, P_GPlus, 193, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_H, 443, check)
      call createCurrent(P_bAnti, P_b, P_H, 811, check)
      call createCurrent(P_eMinus, P_ePlus, P_H, 687, check)
      call createCurrent(P_WMinus, P_WPlus, P_WMinus, P_WPlus, 95, check)
      call createCurrent(P_A, P_bAnti, P_b, 242, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, 457, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_Z, 118, check)
      call createCurrent(P_g, P_bAnti, P_b, 7, check)
      call createCurrent(P_Z, P_Z, P_WMinus, P_WPlus, 54, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, 602, check)
      call createCurrent(P_G0, P_G0, P_A, P_Z, 1145, check)
      call createCurrent(P_b, P_bAnti, P_H, 785, check)
      call createCurrent(P_t, P_A, P_tAnti, 928, check)
      call createCurrent(P_ePlus, P_eMinus, 1141, check)
      call createCurrent(P_A, P_g, P_g, P_Z, 1166, check)
      call createCurrent(P_G0, P_Z, P_GMinus, P_WPlus, 746, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_Z, 880, check)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, 32, check)
      call createCurrent(P_H, P_WPlus, P_WMinus, P_H, 379, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_A, 363, check)
      call createCurrent(P_G0, P_Z, P_H, 103, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, 453, check)
      call createCurrent(P_g, P_Z, P_g, P_A, 1155, check)
      call createCurrent(P_cAnti, P_c, P_Z, 131, check)
      call createCurrent(P_WMinus, P_muPlus, P_nu_mu, 438, check)
      call createCurrent(P_uAnti, P_u, P_H, 270, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_Z, 1007, check)
      call createCurrent(P_Z, P_A, 1091, check)
      call createCurrent(P_GMinus, P_sAnti, P_c, 465, check)
      call createCurrent(P_ghZ, P_H, P_ghZAnti, 878, check)
      call createCurrent(P_Z, P_eMinus, P_ePlus, 675, check)
      call createCurrent(P_A, P_GPlus, P_G0, P_WMinus, 824, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, 445, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, 1006, check)
      call createCurrent(P_t, P_bAnti, P_GMinus, 907, check)
      call createCurrent(P_A, P_tauMinus, P_tauPlus, 621, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_G0, 60, check)
      call createCurrent(P_WMinus, P_sAnti, P_c, 470, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, 458, check)
      call createCurrent(P_bAnti, P_WMinus, P_t, 463, check)
      call createCurrent(P_g, P_Z, P_g, P_g, 1238, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, 322, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_Z, 109, check)
      call createCurrent(P_Z, P_WPlus, P_G0, P_GMinus, 540, check)
      call createCurrent(P_muPlus, P_GMinus, P_nu_mu, 221, check)
      call createCurrent(P_G0, P_H, P_H, P_G0, 177, check)
      call createCurrent(P_bAnti, P_b, P_A, 272, check)
      call createCurrent(P_GMinus, P_H, P_GPlus, 420, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_H, 301, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, 607, check)
      call createCurrent(P_A, P_tauPlus, P_tauMinus, 716, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, 204, check)
      call createCurrent(P_muMinus, P_muPlus, 1121, check)
      call createCurrent(P_H, P_Z, P_Z, 139, check)
      call createCurrent(P_G0, P_G0, P_GPlus, P_GMinus, 385, check)
      call createCurrent(P_Z, P_A, P_WPlus, P_WMinus, 861, check)
      call createCurrent(P_H, P_WMinus, P_A, P_GPlus, 268, check)
      call createCurrent(P_GMinus, P_muPlus, P_nu_mu, 309, check)
      call createCurrent(P_d, P_dAnti, P_g, 895, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_G0, 466, check)
      call createCurrent(P_t, P_tAnti, P_Z, 868, check)
      call createCurrent(P_GPlus, P_g, P_g, P_GMinus, 1246, check)
      call createCurrent(P_GPlus, P_H, P_GMinus, 690, check)
      call createCurrent(P_Z, P_Z, P_Z, P_A, 1172, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_G0, 518, check)
      call createCurrent(P_b, P_bAnti, P_Z, 524, check)
      call createCurrent(P_G0, P_muPlus, P_muMinus, 11, check)
      call createCurrent(P_A, P_nu_mu, P_nu_muAnti, 1137, check)
      call createCurrent(P_GPlus, P_nu_tauAnti, P_tauMinus, 431, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, 435, check)
      call createCurrent(P_GMinus, P_A, P_G0, P_WPlus, 912, check)
      call createCurrent(P_g, P_g, P_Z, P_Z, 1220, check)
      call createCurrent(P_H, P_H, P_WPlus, P_WMinus, 879, check)
      call createCurrent(P_Z, P_GPlus, P_A, P_GMinus, 148, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_Z, 389, check)
      call createCurrent(P_G0, P_tauMinus, P_tauPlus, 775, check)
      call createCurrent(P_eMinus, P_H, P_ePlus, 1043, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, 733, check)
      call createCurrent(P_G0, P_s, P_sAnti, 15, check)
      call createCurrent(P_g, P_ghG, P_ghGAnti, 529, check)
      call createCurrent(P_A, P_H, P_Z, P_H, 1107, check)
      call createCurrent(P_g, P_H, P_g, P_H, 1207, check)
      call createCurrent(P_H, P_b, P_bAnti, 141, check)
      call createCurrent(P_b, P_GPlus, P_tAnti, 416, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_Z, 997, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, 234, check)
      call createCurrent(P_GMinus, P_GPlus, P_GMinus, P_GPlus, 513, check)
      call createCurrent(P_Z, P_A, P_H, P_H, 1051, check)
      call createCurrent(P_dAnti, P_G0, P_d, 951, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Z, 660, check)
      call createCurrent(P_A, P_A, 1090, check)
      call createCurrent(P_g, P_ghGAnti, P_ghG, 525, check)
      call createCurrent(P_muPlus, P_muMinus, P_A, 380, check)
      call createCurrent(P_Z, P_Z, P_H, 481, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, 460, check)
      call createCurrent(P_muMinus, P_muPlus, P_Z, 265, check)
      call createCurrent(P_eMinus, P_Z, P_ePlus, 401, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, 510, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, 341, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, 1130, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, 648, check)
      call createCurrent(P_g, P_g, P_GMinus, P_GPlus, 1191, check)
      call createCurrent(P_WPlus, P_cAnti, P_s, 657, check)
      call createCurrent(P_WMinus, P_H, P_H, P_WPlus, 521, check)
      call createCurrent(P_G0, P_GMinus, P_A, P_WPlus, 279, check)
      call createCurrent(P_WPlus, P_nu_eAnti, P_eMinus, 298, check)
      call createCurrent(P_WPlus, P_A, P_G0, P_GMinus, 611, check)
      call createCurrent(P_tAnti, P_t, P_G0, 494, check)
      call createCurrent(P_A, P_WMinus, P_H, P_GPlus, 299, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghWm, 499, check)
      call createCurrent(P_s, P_sAnti, P_g, 805, check)
      call createCurrent(P_b, P_WPlus, P_tAnti, 310, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_G0, 941, check)
      call createCurrent(P_tAnti, P_g, P_t, 946, check)
      call createCurrent(P_GMinus, P_Z, P_G0, P_WPlus, 52, check)
      call createCurrent(P_Z, P_G0, P_WMinus, P_GPlus, 998, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, 446, check)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, 126, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_H, 754, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_A, 384, check)
      call createCurrent(P_H, P_A, P_WPlus, P_GMinus, 830, check)
      call createCurrent(P_GPlus, P_WMinus, P_GMinus, P_WPlus, 330, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, 387, check)
      call createCurrent(P_tAnti, P_t, P_H, 800, check)
      call createCurrent(P_u, P_uAnti, P_g, 632, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WPlus, 179, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_A, 1084, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, 670, check)
      call createCurrent(P_GPlus, P_H, P_A, P_WMinus, 701, check)
      call createCurrent(P_A, P_Z, P_GPlus, P_GMinus, 560, check)
      call createCurrent(P_G0, P_GPlus, P_A, P_WMinus, 185, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, 927, check)
      call createCurrent(P_Z, P_WMinus, P_G0, P_GPlus, 447, check)
      call createCurrent(P_Z, P_G0, 1138, check)
      call createCurrent(P_GMinus, P_A, P_A, P_GPlus, 526, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_H, 264, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_A, 468, check)
      call createCurrent(P_tauPlus, P_H, P_tauMinus, 652, check)
      call createCurrent(P_tauMinus, P_A, P_tauPlus, 612, check)
      call createCurrent(P_GMinus, P_WMinus, P_WPlus, P_GPlus, 728, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, 63, check)
      call createCurrent(P_GPlus, P_GMinus, P_GMinus, P_GPlus, 960, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_Z, 16, check)
      call createCurrent(P_A, P_G0, P_WMinus, P_GPlus, 455, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, 610, check)
      call createCurrent(P_WPlus, P_GMinus, 1094, check)
      call createCurrent(P_b, P_H, P_bAnti, 829, check)
      call createCurrent(P_A, P_WPlus, P_A, P_WMinus, 429, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_G0, 666, check)
      call createCurrent(P_uAnti, P_g, P_u, 877, check)
      call createCurrent(P_GPlus, P_G0, P_Z, P_WMinus, 533, check)
      call createCurrent(P_WPlus, P_H, P_WMinus, 865, check)
      call createCurrent(P_g, P_g, P_Z, P_A, 1178, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_G0, 18, check)
      call createCurrent(P_WPlus, P_G0, P_A, P_GMinus, 289, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_Z, 616, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, 949, check)
      call createCurrent(P_G0, P_A, 1115, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_H, 135, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_Z, 188, check)
      call createCurrent(P_d, P_GPlus, P_uAnti, 328, check)
      call createCurrent(P_nu_tauAnti, P_GPlus, P_tauMinus, 993, check)
      call createCurrent(P_A, P_WPlus, P_Z, P_WMinus, 240, check)
      call createCurrent(P_ePlus, P_A, P_eMinus, 589, check)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, 684, check)
      call createCurrent(P_G0, P_ePlus, P_eMinus, 169, check)
      call createCurrent(P_g, P_GMinus, P_g, P_GPlus, 1175, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, 294, check)
      call createCurrent(P_G0, P_G0, P_H, P_H, 295, check)
      call createCurrent(P_H, P_Z, P_WMinus, P_GPlus, 981, check)
      call createCurrent(P_tAnti, P_A, P_t, 867, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, P_Z, 818, check)
      call createCurrent(P_Z, P_G0, P_A, P_G0, 1108, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, 848, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_WMinus, 168, check)
      call createCurrent(P_cAnti, P_c, P_H, 506, check)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, 482, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_Z, 933, check)
      call createCurrent(P_g, P_G0, P_G0, P_g, 1225, check)
      call createCurrent(P_c, P_WMinus, P_sAnti, 548, check)
      call createCurrent(P_u, P_Z, P_uAnti, 73, check)
      call createCurrent(P_ghZAnti, P_H, P_ghZ, 176, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_H, 793, check)
      call createCurrent(P_g, P_GPlus, P_g, P_GMinus, 1147, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_Z, 511, check)
      call createCurrent(P_H, P_Z, P_A, 1123, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, 280, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_A, 48, check)
      call createCurrent(P_nu_muAnti, P_A, P_nu_mu, 1110, check)
      call createCurrent(P_s, P_sAnti, P_A, 840, check)
      call createCurrent(P_g, P_g, P_A, P_A, 1194, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_GPlus, 409, check)
      call createCurrent(P_H, P_ghWp, P_ghWpAnti, 26, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, 92, check)
      call createCurrent(P_WMinus, P_WPlus, P_GMinus, P_GPlus, 629, check)
    end subroutine createCurrents

    subroutine check_vertices_mdl()
      call createCurrents(.true.)
    end subroutine check_vertices_mdl

    subroutine get_vertex_lorentz_rank_mdl(ty,cc,mr)
      integer, intent(in) :: ty
      logical, intent(in) :: cc(0:)
      integer, intent(out) :: mr
      select case(ty)
      case(4)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(5)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(9)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(15)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(16)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(17)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(18)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(20)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(21)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(22)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(27)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(28)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(29)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(43)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(44)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(45)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(46)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(47)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(48)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(49)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(51)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(52)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(53)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(54)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(58)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(64)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(67)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(70)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(71)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(73)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case default
        mr = 0
      end select 
    end subroutine get_vertex_lorentz_rank_mdl
end module class_vertices
